@@ -103,7 +103,7 @@ func convertPostureReportToJunitResult(postureResult *reporthandling.PostureRepo
 			testCase := JUnitTestCase{}
 			testCase.Name = controlReports.Name
 			testCase.Classname = "Kubescape"
-			testCase.Time = "0"
+			testCase.Time = postureResult.ReportGenerationTime.String()
 			if 0 < len(controlReports.RuleReports[0].RuleResponses) {
 
 				testCase.Resources = controlReports.GetNumberOfResources()
