@@ -9,10 +9,10 @@ var INDENT = "   "
 const EmptyPercentage = "NaN"
 
 const (
-	PrettyFormat       string = "pretty-printer"
-	JsonFormat         string = "json"
-	JunitResultFormat  string = "junit"
-	PrometheusFormat   string = "prometheus"
+	PrettyFormat      string = "pretty-printer"
+	JsonFormat        string = "json"
+	JunitResultFormat string = "junit"
+	PrometheusFormat  string = "prometheus"
 )
 
 type IPrinter interface {
@@ -21,15 +21,15 @@ type IPrinter interface {
 	Score(score float32)
 }
 
-func GetPrinter(printFormat string) IPrinter {
+func GetPrinter(printFormat string, verboseMode bool) IPrinter {
 	switch printFormat {
 	case JsonFormat:
 		return NewJsonPrinter()
 	case JunitResultFormat:
 		return NewJunitPrinter()
 	case PrometheusFormat:
-		return NewPrometheusPrinter()
+		return NewPrometheusPrinter(verboseMode)
 	default:
-		return NewPrettyPrinter()
+		return NewPrettyPrinter(verboseMode)
 	}
 }
