@@ -42,19 +42,12 @@ func (resultsHandler *ResultsHandler) HandleResults(scanInfo *cautils.ScanInfo)
 
 // CalculatePostureScore calculate final score
 func CalculatePostureScore(postureReport *reporthandling.PostureReport) float32 {
-	lowestScore := float32(100)
+	failedResources := []string{}
+	allResources := []string{}
 	for _, frameworkReport := range postureReport.FrameworkReports {
-		totalFailed := frameworkReport.GetNumberOfFailedResources()
-		totalResources := frameworkReport.GetNumberOfResources()
-
-		frameworkScore := float32(0)
-		if float32(totalResources) > 0 {
-			frameworkScore = (float32(totalResources) - float32(totalFailed)) / float32(totalResources)
-		}
-		if lowestScore > frameworkScore {
-			lowestScore = frameworkScore
-		}
+		failedResources = reporthandling.GetUniqueResourcesIDs(append(failedResources, frameworkReport.ListResourcesIDs().GetFailedResources()...))
+		allResources = reporthandling.GetUniqueResourcesIDs(append(allResources, frameworkReport.ListResourcesIDs().GetAllResources()...))
 	}
 
-	return lowestScore
+	return (float32(len(allResources)) - float32(len(failedResources))) / float32(len(allResources))
 }
